function fig2_4()

close all
u0 = @(x) x.*(1-x);

nx1 = 10;
nx2 = 20;
dx1 = 1/nx1;
dx2 = 1/nx2;
dt1 = 0.5*dx1^2;
dt2 = 0.5*dx2^2;
nt1 = round(1/dt1);
nt2 = round(1/dt2);
x1 = linspace(0,1,nx1+1);
x2 = linspace(0,1,nx2+1);


En1 = zeros(nt1,1);
En2 = zeros(nt2,1);

%% compute exact solution
m = 1:1000;
am = 4./(m.^3*pi^3).*(1-cos(m*pi));
u = @(x,t) (am*(exp(-m'.^2*pi^2*t).*sin(pi.*m'.*x)))';  % x should be a row vector 

%% numerical solution
U1 = chap2_explicit(nx1, nt1, dt1, u0);
U2 = chap2_explicit(nx2, nt2, dt2, u0);


%% compute errors
for i = 1:nt1
    En1(i) = max(abs(U1(:,i+1) - u(x1, i*dt1)));
end

for i = 1:nt2
    En2(i) = max(abs(U2(:,i+1) - u(x2, i*dt2)));
end

%% figure plot
plot(dt1*(1:nt1),log10(En1),'-')
hold on
plot(dt2*(1:nt2),log10(En2),'-')

xlabel('$t_n$','Interpreter','latex')
ylabel('$\log_{10}E_n$','Interpreter','latex')
savefig('fig2_4')
end